@@ -1,4 +1,4 @@
-__all__ = ('OrderPoint', 'OrderObjectPoint')
+__all__ = ('OrderPoint', 'OrderObjectPoint', 'SchedulePoint')
 
 from djmoney.contrib.django_rest_framework import MoneyField
 from expressmoney.api import *
@@ -14,16 +14,19 @@ class OrderCreateContract(Contract):
 
 class OrderReadContract(OrderCreateContract):
     NEW = 'NEW'
+    DECLINED = 'DECLINED'
     LOAN_CREATED = 'LOAN_CREATED'
     EXPIRED = 'EXPIRED'
     STATUS_CHOICES = (
         (NEW, NEW),
+        (DECLINED, DECLINED),
         (LOAN_CREATED, LOAN_CREATED),
         (EXPIRED, EXPIRED),
     )
 
     id = serializers.IntegerField(min_value=1)
     created = serializers.DateTimeField()
+    updated = serializers.DateTimeField()
     user_id = serializers.IntegerField(min_value=1)
     status = serializers.ChoiceField(choices=STATUS_CHOICES)
     requested_period = serializers.IntegerField(min_value=1)
@@ -35,6 +38,14 @@ class OrderReadContract(OrderCreateContract):
     sign = serializers.IntegerField(min_value=1)
     contract_demo = serializers.CharField(max_length=256, allow_blank=True)
     ip = serializers.IPAddressField()
+    product = serializers.IntegerField()
+
+
+class ScheduleReadContract(Contract):
+    order = serializers.IntegerField()
+    is_paid = serializers.BooleanField()
+    date = serializers.DateField()
+    amount = MoneyField(max_digits=7, decimal_places=0)
 
 
 class OrderID(ID):
@@ -43,6 +54,12 @@ class OrderID(ID):
     _view_set = 'order'
 
 
+class ScheduleID(ID):
+    _service = SERVICE
+    _app = 'orders'
+    _view_set = 'schedule'
+
+
 class OrderPoint(ListPointMixin, CreatePointMixin, ContractPoint):
     _point_id = OrderID()
     _read_contract = OrderReadContract
@@ -52,3 +69,8 @@ class OrderPoint(ListPointMixin, CreatePointMixin, ContractPoint):
 class OrderObjectPoint(RetrievePointMixin, ContractObjectPoint):
     _point_id = OrderID()
     _read_contract = OrderReadContract
+
+
+class SchedulePoint(ListPointMixin, CreatePointMixin):
+    _point_id = ScheduleID()
+    _read_contract = ScheduleReadContract
