@@ -5,11 +5,6 @@ from expressmoney.api import *
 SERVICE = 'loans'
 
 
-class AmountLimitContract(Contract):
-    amount = serializers.DecimalField(max_digits=7, decimal_places=0)
-    credit_score = serializers.DecimalField(max_digits=3, decimal_places=2)
-
-
 class ProductContract(Contract):
     created = serializers.DateTimeField()
     updated = serializers.DateTimeField()
@@ -53,7 +48,6 @@ class OrderReadContract(OrderCreateContract):
                                                )
     period_approved = serializers.IntegerField(allow_null=True)
     product = ProductContract()
-    amount_limit = AmountLimitContract()
     status = serializers.ChoiceField(choices=STATUS_CHOICES)
     contract_demo = serializers.CharField(max_length=256, allow_blank=True)
 
