@@ -1,4 +1,4 @@
-__all__ = ('BlackListPoint',)
+__all__ = ('BlackListPoint', 'BlackListObjectPoint')
 
 from expressmoney.api import *
 
@@ -25,3 +25,8 @@ class BlackListPoint(ListPointMixin, CreatePointMixin, ContractPoint):
     _point_id = BlackListID()
     _read_contract = BlackListReadContract
     _create_contract = BlackListCreateContract
+
+
+class BlackListObjectPoint(RetrievePointMixin, ContractObjectPoint):
+    _point_id = BlackListID()
+    _read_contract = BlackListReadContract
